==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/ScaleRuleAuthArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.ScaleRuleAuthArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Auth Secrets for Scale Rule
 * @property secretRef Name of the secret from which to pull the auth params.
 * @property triggerParameter Trigger Parameter that uses the secret
 */
public data class ScaleRuleAuthArgs(
    public val secretRef: Output<String>? = null,
    public val triggerParameter: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.ScaleRuleAuthArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.ScaleRuleAuthArgs =
        com.pulumi.azurenative.app.inputs.ScaleRuleAuthArgs.builder()
            .secretRef(secretRef?.applyValue({ args0 -> args0 }))
            .triggerParameter(triggerParameter?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScaleRuleAuthArgs].
 */
@PulumiTagMarker
public class ScaleRuleAuthArgsBuilder internal constructor() {
    private var secretRef: Output<String>? = null

    private var triggerParameter: Output<String>? = null

    /**
     * @param value Name of the secret from which to pull the auth params.
     */
    @JvmName("bupboxtnbckhelnf")
    public suspend fun secretRef(`value`: Output<String>) {
        this.secretRef = value
    }

    /**
     * @param value Trigger Parameter that uses the secret
     */
    @JvmName("sunwbwkrstjajkib")
    public suspend fun triggerParameter(`value`: Output<String>) {
        this.triggerParameter = value
    }

    /**
     * @param value Name of the secret from which to pull the auth params.
     */
    @JvmName("psuayqmrdurrqvlx")
    public suspend fun secretRef(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretRef = mapped
    }

    /**
     * @param value Trigger Parameter that uses the secret
     */
    @JvmName("scqbrnhyipkluves")
    public suspend fun triggerParameter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.triggerParameter = mapped
    }

    internal fun build(): ScaleRuleAuthArgs = ScaleRuleAuthArgs(
        secretRef = secretRef,
        triggerParameter = triggerParameter,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/ScaleRuleAuthArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.ScaleRuleAuthArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Auth Secrets for Scale Rule
 * @property secretRef Name of the secret from which to pull the auth params.
 * @property triggerParameter Trigger Parameter that uses the secret
 */
public data class ScaleRuleAuthArgs(
    public val secretRef: Output<String>? = null,
    public val triggerParameter: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.ScaleRuleAuthArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.ScaleRuleAuthArgs =
        com.pulumi.azurenative.app.inputs.ScaleRuleAuthArgs.builder()
            .secretRef(secretRef?.applyValue({ args0 -> args0 }))
            .triggerParameter(triggerParameter?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScaleRuleAuthArgs].
 */
@PulumiTagMarker
public class ScaleRuleAuthArgsBuilder internal constructor() {
    private var secretRef: Output<String>? = null

    private var triggerParameter: Output<String>? = null

    /**
     * @param value Name of the secret from which to pull the auth params.
     */
    @JvmName("jdvlbcqvbspvercc")
    public suspend fun secretRef(`value`: Output<String>) {
        this.secretRef = value
    }

    /**
     * @param value Trigger Parameter that uses the secret
     */
    @JvmName("jhidlkfqyufpkxhf")
    public suspend fun triggerParameter(`value`: Output<String>) {
        this.triggerParameter = value
    }

    /**
     * @param value Name of the secret from which to pull the auth params.
     */
    @JvmName("cwbsgvtbvksbofjm")
    public suspend fun secretRef(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretRef = mapped
    }

    /**
     * @param value Trigger Parameter that uses the secret
     */
    @JvmName("fakajmtynxgjioqq")
    public suspend fun triggerParameter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.triggerParameter = mapped
    }

    internal fun build(): ScaleRuleAuthArgs = ScaleRuleAuthArgs(
        secretRef = secretRef,
        triggerParameter = triggerParameter,
    )
}
